@@ -6,7 +6,7 @@ from apigee import utils_init
 
 APP = "apigeecli"
 CMD = "apigee"
-__version__ = "0.53.8"
+__version__ = "0.53.10"
 description = "(DEPRECATED) apigeecli simplifies and automates Apigee Edge API usage."
 long_description = """The Apigee Edge command-line interface is an unofficial Python command-line tool built to simplify and automate Apigee Edge API usage, with support for SSO, MFA, and basic authentication."""
 
@@ -26,6 +26,8 @@ APIGEE_CLI_EXCEPTIONS_LOG_FILE = utils_init.join_path_components(
     APIGEE_CLI_DIRECTORY, "exceptions.log")
 APIGEE_CLI_IS_MACHINE_USER = utils_init.is_truthy_envvar(
     getenv("APIGEE_CLI_IS_MACHINE_USER"))
+APIGEE_CLI_PLUGIN_INFO_FILE = "apigee-cli-info.json"
+APIGEE_CLI_PLUGIN_INFO_FILE_LEGACY = "apigee-cli.info"
 APIGEE_CLI_PLUGINS_CONFIG_FILE = utils_init.join_path_components(
     APIGEE_CLI_PLUGINS_DIRECTORY, "config")
 APIGEE_CLI_PLUGINS_PATH = utils_init.join_path_components(
@@ -45,4 +47,4 @@ APIGEE_ZONENAME = getenv("APIGEE_ZONENAME")
 APIGEE_ZONENAME_OAUTH_URL = "https://{zonename}.login.apigee.com/oauth/token"
 
 builtins.APIGEE_CLI_TOGGLE_SILENT = APIGEE_CLI_TOGGLE_SILENT
-builtins.APIGEE_CLI_TOGGLE_VERBOSE = APIGEE_CLI_TOGGLE_VERBOSE
+builtins.APIGEE_CLI_TOGGLE_VERBOSE = APIGEE_CLI_TOGGLE_VERBOSE
\ No newline at end of file
