@@ -2,6 +2,7 @@ import json
 
 
 class ApiproductsSerializer:
+
     def serialize_details(self, apiproducts, format, prefix=None):
         resp = apiproducts
         if format == "text":
@@ -9,8 +10,7 @@ class ApiproductsSerializer:
         apiproducts = apiproducts.json()
         if prefix:
             apiproducts = [
-                apiproduct
-                for apiproduct in apiproducts
+                apiproduct for apiproduct in apiproducts
                 if apiproduct.startswith(prefix)
             ]
         if format == "dict":
