@@ -2,11 +2,14 @@ import click
 
 
 class AliasedGroup(click.Group):
+
     def get_command(self, ctx, cmd_name):
         rv = click.Group.get_command(self, ctx, cmd_name)
         if rv is not None:
             return rv
-        matches = [x for x in self.list_commands(ctx) if x.startswith(cmd_name)]
+        matches = [
+            x for x in self.list_commands(ctx) if x.startswith(cmd_name)
+        ]
         if not matches:
             return None
         elif len(matches) == 1:
