@@ -1,7 +1,7 @@
 import click
 
 from apigee import console
-from apigee.auth import common_auth_options, gen_auth
+from apigee.auth import common_auth_options, generate_authentication
 from apigee.keystores.keystores import Keystores
 from apigee.prefix import common_prefix_options
 from apigee.silent import common_silent_options
@@ -9,7 +9,8 @@ from apigee.verbose import common_verbose_options
 
 
 @click.group(
-    help="A list of URIs used to create, modify, and delete keystores and truststores."
+    help=
+    "A list of URIs used to create, modify, and delete keystores and truststores."
 )
 def keystores():
     pass
@@ -39,26 +40,24 @@ def delete(*args, **kwargs):
     _delete_a_keystore_or_truststore(*args, **kwargs)
 
 
-def _list_all_keystores_and_truststores(
-    username,
-    password,
-    mfa_secret,
-    token,
-    zonename,
-    org,
-    profile,
-    environment,
-    prefix=None,
-    **kwargs
-):
+def _list_all_keystores_and_truststores(username,
+                                        password,
+                                        mfa_secret,
+                                        token,
+                                        zonename,
+                                        org,
+                                        profile,
+                                        environment,
+                                        prefix=None,
+                                        **kwargs):
     return Keystores(
-        gen_auth(username, password, mfa_secret, token, zonename), org, None
-    ).list_all_keystores_and_truststores(environment, prefix=prefix)
+        generate_authentication(username, password, mfa_secret, token,
+                                zonename), org,
+        None).list_all_keystores_and_truststores(environment, prefix=prefix)
 
 
 @keystores.command(
-    help="Returns a list of all keystores and truststores in the environment."
-)
+    help="Returns a list of all keystores and truststores in the environment.")
 @common_auth_options
 @common_prefix_options
 @common_silent_options
@@ -68,26 +67,17 @@ def list(*args, **kwargs):
     console.echo(_list_all_keystores_and_truststores(*args, **kwargs))
 
 
-def _get_a_keystore_or_truststore(
-    username,
-    password,
-    mfa_secret,
-    token,
-    zonename,
-    org,
-    profile,
-    name,
-    environment,
-    **kwargs
-):
-    return (
-        Keystores(gen_auth(username, password, mfa_secret, token, zonename), org, name)
-        .get_a_keystore_or_truststore(environment)
-        .text
-    )
+def _get_a_keystore_or_truststore(username, password, mfa_secret, token,
+                                  zonename, org, profile, name, environment,
+                                  **kwargs):
+    return (Keystores(
+        generate_authentication(username, password, mfa_secret, token,
+                                zonename), org,
+        name).get_a_keystore_or_truststore(environment).text)
 
 
-@keystores.command(help="Returns a specific keystore or truststore in the environment.")
+@keystores.command(
+    help="Returns a specific keystore or truststore in the environment.")
 @common_auth_options
 @common_silent_options
 @common_verbose_options
@@ -109,27 +99,20 @@ def test(*args, **kwargs):
     _test_a_keystore_or_truststore(*args, **kwargs)
 
 
-def _get_cert_details_from_a_keystore_or_truststore(
-    username,
-    password,
-    mfa_secret,
-    token,
-    zonename,
-    org,
-    profile,
-    name,
-    environment,
-    cert_name,
-    **kwargs
-):
-    return (
-        Keystores(gen_auth(username, password, mfa_secret, token, zonename), org, name)
-        .get_cert_details_from_a_keystore_or_truststore(environment, cert_name)
-        .text
-    )
+def _get_cert_details_from_a_keystore_or_truststore(username, password,
+                                                    mfa_secret, token,
+                                                    zonename, org, profile,
+                                                    name, environment,
+                                                    cert_name, **kwargs):
+    return (Keystores(
+        generate_authentication(username, password, mfa_secret, token,
+                                zonename), org,
+        name).get_cert_details_from_a_keystore_or_truststore(
+            environment, cert_name).text)
 
 
-@keystores.command(help="Returns a specific cert from a keystore or truststore.")
+@keystores.command(
+    help="Returns a specific cert from a keystore or truststore.")
 @common_auth_options
 @common_silent_options
 @common_verbose_options
@@ -137,25 +120,26 @@ def _get_cert_details_from_a_keystore_or_truststore(
 @click.option("--cert-name", help="cert name", required=True)
 @click.option("-e", "--environment", help="environment", required=True)
 def get_cert(*args, **kwargs):
-    console.echo(_get_cert_details_from_a_keystore_or_truststore(*args, **kwargs))
+    console.echo(
+        _get_cert_details_from_a_keystore_or_truststore(*args, **kwargs))
 
 
-def _get_all_certs_from_a_keystore_or_truststore(
-    username,
-    password,
-    mfa_secret,
-    token,
-    zonename,
-    org,
-    profile,
-    name,
-    environment,
-    prefix=None,
-    **kwargs
-):
+def _get_all_certs_from_a_keystore_or_truststore(username,
+                                                 password,
+                                                 mfa_secret,
+                                                 token,
+                                                 zonename,
+                                                 org,
+                                                 profile,
+                                                 name,
+                                                 environment,
+                                                 prefix=None,
+                                                 **kwargs):
     return Keystores(
-        gen_auth(username, password, mfa_secret, token, zonename), org, name
-    ).get_all_certs_from_a_keystore_or_truststore(environment, prefix=prefix)
+        generate_authentication(username, password, mfa_secret, token,
+                                zonename), org,
+        name).get_all_certs_from_a_keystore_or_truststore(environment,
+                                                          prefix=prefix)
 
 
 @keystores.command(help="Returns all certs from a keystore or truststore.")
@@ -181,24 +165,12 @@ def delete_cert(*args, **kwargs):
     _delete_cert_from_a_keystore_or_truststore(*args, **kwargs)
 
 
-def _export_a_cert(
-    username,
-    password,
-    mfa_secret,
-    token,
-    zonename,
-    org,
-    profile,
-    name,
-    environment,
-    cert_name,
-    **kwargs
-):
-    return (
-        Keystores(gen_auth(username, password, mfa_secret, token, zonename), org, name)
-        .export_a_cert(environment, cert_name)
-        .text
-    )
+def _export_a_cert(username, password, mfa_secret, token, zonename, org,
+                   profile, name, environment, cert_name, **kwargs):
+    return (Keystores(
+        generate_authentication(username, password, mfa_secret, token,
+                                zonename), org,
+        name).export_a_cert(environment, cert_name).text)
 
 
 @keystores.command(help="Export a cert from a keystore or truststore.")
@@ -248,22 +220,21 @@ def create_alias(*args, **kwargs):
     _create_an_alias_by_generating_a_self_signed_certificate(*args, **kwargs)
 
 
-def _list_aliases(
-    username,
-    password,
-    mfa_secret,
-    token,
-    zonename,
-    org,
-    profile,
-    name,
-    environment,
-    prefix=None,
-    **kwargs
-):
+def _list_aliases(username,
+                  password,
+                  mfa_secret,
+                  token,
+                  zonename,
+                  org,
+                  profile,
+                  name,
+                  environment,
+                  prefix=None,
+                  **kwargs):
     return Keystores(
-        gen_auth(username, password, mfa_secret, token, zonename), org, name
-    ).list_aliases(environment, prefix=prefix)
+        generate_authentication(username, password, mfa_secret, token,
+                                zonename), org,
+        name).list_aliases(environment, prefix=prefix)
 
 
 @keystores.command(help="Returns a list of all the aliases in the keystore.")
@@ -277,24 +248,12 @@ def list_aliases(*args, **kwargs):
     console.echo(_list_aliases(*args, **kwargs))
 
 
-def _get_alias(
-    username,
-    password,
-    mfa_secret,
-    token,
-    zonename,
-    org,
-    profile,
-    name,
-    environment,
-    alias_name,
-    **kwargs
-):
-    return (
-        Keystores(gen_auth(username, password, mfa_secret, token, zonename), org, name)
-        .get_alias(environment, alias_name)
-        .text
-    )
+def _get_alias(username, password, mfa_secret, token, zonename, org, profile,
+               name, environment, alias_name, **kwargs):
+    return (Keystores(
+        generate_authentication(username, password, mfa_secret, token,
+                                zonename), org,
+        name).get_alias(environment, alias_name).text)
 
 
 @keystores.command(help="Returns details about an alias.")
@@ -332,28 +291,18 @@ def generate_csr_for_alias(*args, **kwargs):
     _generate_a_csr_for_an_alias(*args, **kwargs)
 
 
-def _export_a_certificate_for_an_alias(
-    username,
-    password,
-    mfa_secret,
-    token,
-    zonename,
-    org,
-    profile,
-    name,
-    environment,
-    alias_name,
-    **kwargs
-):
-    return (
-        Keystores(gen_auth(username, password, mfa_secret, token, zonename), org, name)
-        .export_a_certificate_for_an_alias(environment, alias_name)
-        .text
-    )
+def _export_a_certificate_for_an_alias(username, password, mfa_secret, token,
+                                       zonename, org, profile, name,
+                                       environment, alias_name, **kwargs):
+    return (Keystores(
+        generate_authentication(username, password, mfa_secret, token,
+                                zonename), org,
+        name).export_a_certificate_for_an_alias(environment, alias_name).text)
 
 
 @keystores.command(
-    help="Exports a certificate or certificate chain for the specified alias in a keystore."
+    help=
+    "Exports a certificate or certificate chain for the specified alias in a keystore."
 )
 @common_auth_options
 @common_silent_options
