@@ -2,6 +2,7 @@ import json
 
 
 class MaskconfigsSerializer:
+
     def serialize_details(self, maskconfigs, format, prefix=None):
         resp = maskconfigs
         if format == "text":
@@ -9,8 +10,7 @@ class MaskconfigsSerializer:
         maskconfigs = maskconfigs.json()
         if prefix:
             maskconfigs = [
-                maskconfig
-                for maskconfig in maskconfigs
+                maskconfig for maskconfig in maskconfigs
                 if maskconfig.startswith(prefix)
             ]
         return json.dumps(maskconfigs) if format == "json" else resp
